OC.L10N.register(
    "settings",
    {
    "Migration in progress. Please wait until the migration is finished" : "Kolimine on käimas. Palun oota, kuni see on lõpetatud",
    "Migration started …" : "Kolimist on alustatud ...",
    "Saved" : "Salvestatud",
    "Not saved" : "Ei ole salvestatud",
    "Sending…" : "Saadan...",
    "Email sent" : "E-kiri on saadetud",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Tekkis viga. Palun lae üles ASCII kodeeringud PEM sertifikaat.",
    "Valid until {date}" : "Kehtib kuni {date}",
    "Delete" : "Kustuta",
    "Local" : "Kohalik",
    "Private" : "Privaatne",
    "Only visible to local users" : "Ainult nähtav kohalikele kasutajatele",
    "Only visible to you" : "Ainult sinule nähtav",
    "Contacts" : "Kontaktid",
    "Visible to local users and to trusted servers" : "Nähtav kohelikele kasutajatele ja usaldatud serveritele",
    "Public" : "Avalik",
    "Will be synced to a global and public address book" : "Sünkroniseeritakse globaalsesse ja avalikku aadressiraamatusse",
    "Verify" : "Kontrolli",
    "Verifying …" : "Kontrollin ...",
    "Unable to change password" : "Ei suuda parooli muuta",
    "Very weak password" : "Väga nõrk parool",
    "Weak password" : "Nõrk parool",
    "So-so password" : "Enam-vähem sobiv parool",
    "Good password" : "Hea parool",
    "Strong password" : "Väga hea parool",
    "Select a profile picture" : "Vali profiili pilt",
    "Week starts on {fdow}" : "Nädala esimene päev: {fdow}",
    "Groups" : "Grupid",
    "{actor} changed your password" : "{actor} muutis sinu parooli",
    "You changed your password" : "Sa muutsid oma parooli",
    "Your password was reset by an administrator" : "Administraator lähtestas sinu parooli",
    "{actor} changed your email address" : "{actor} muutis sinu e-posti aadressi",
    "You changed your email address" : "Sa muutsid oma e-posti aadressi",
    "Your email address was changed by an administrator" : "Administraator muutis sinu e-posti aadressi",
    "Security" : "Turvalisus",
    "You successfully logged in using two-factor authentication (%1$s)" : "Logisid edukalt sisse, kasutades kaheastmelist autentimiset (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Sisselogimiskatse, kasutades kaheastmelist autentimist, ebaõnnestus (%1$s)",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Sinu <strong>parooli</strong> või <strong>e-posti aadressi</strong> muudeti",
    "Couldn't remove app." : "Ei suutnud rakendit eemaldada.",
    "Couldn't update app." : "Rakenduse uuendamine ebaõnnestus.",
    "Wrong password" : "Vale parool",
    "No user supplied" : "Kasutajat ei sisestatud",
    "Authentication error" : "Autentimise viga",
    "Wrong admin recovery password. Please check the password and try again." : "Vale administraatori taasteparool. Palun kontrolli parooli ning proovi uuesti.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "Paigaldan ja uuendan rakendusi läbi rakenduste poe või liitpilve jagamise",
    "Federated Cloud Sharing" : "Jagamine liitpilves",
    "Invalid SMTP password." : "Vale SMTP parool.",
    "Email setting test" : "E-posti sätete kontroll",
    "Well done, %s!" : "Suurepärane, %s!",
    "If you received this email, the email configuration seems to be correct." : "Kui saite selle kirja, näib e-posti seadistus õige.",
    "Email could not be sent. Check your mail server log" : "E-posti ei saanud saata. Kontrollige oma meiliserveri logi",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "E-posti saatmisel ilmnes viga. Palun kontrollige seadeid. (Viga: %s)",
    "You need to set your user email before being able to send test emails." : "Pead seadistama oma e-postienne kui on võimalik saata test-kirju.",
    "Invalid mail address" : "Vigane e-posti aadress",
    "Settings saved" : "Seaded salvestatud",
    "Unable to change full name" : "Täispika nime muutmine ebaõnnestus",
    "Unable to change email address" : "E-posti aadressi muutmine ebaõnnestus",
    "%1$s changed your password on %2$s." : "%1$s muutis su parooli %2$s.",
    "Your password on %s was changed." : "Sinu %s parool muudeti.",
    "Your password on %s was reset by an administrator." : "Administraator lähtestas sinu %s parooli.",
    "Password for %1$s changed on %2$s" : "%1$s parool muudetud %2$s",
    "Password changed for %s" : "%s parool muudetud",
    "If you did not request this, please contact an administrator." : "Kui sa pole seda taotlenud, võta ühendust administraatoriga.",
    "Your email address on %s was changed." : "Sinu %s e-posti aadressi muudeti.",
    "Your email address on %s was changed by an administrator." : "Administraator muutis sinu %s e-posti aadressi.",
    "Email address for %1$s changed on %2$s" : "%1$s e-posti aadress muudetud %2$s",
    "Email address changed for %s" : "%s e-posti aadress muudetud",
    "The new email address is %s" : "Uus e-posti aadress on %s",
    "Your %s account was created" : "Sinu %s konto on loodud",
    "Welcome aboard" : "Tere tulemast",
    "Welcome aboard %s" : "Tere tulemast %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Tere tulemast oma %s kontole. Sa saad lisada, kaitsta ja jagada oma andmeid.",
    "Your username is: %s" : "Sinu kasutajanimi on: %s",
    "Set your password" : "Määra oma parool",
    "Go to %s" : "Mine %s",
    "Install Client" : "Paigalda kliendiprogramm",
    "Unlimited" : "Piiramatult",
    "Limit to groups" : "Luba gruppidele",
    "Official" : "Ametlik",
    "Remove" : "Eemalda",
    "Disable" : "Lülita välja",
    "All" : "Kõik",
    "No results" : "Vasteid ei leitud",
    "Visit website" : "Külasta veebisaiti",
    "Report a bug" : "Teata veast",
    "User documentation" : "Kasutaja dokumentatsioon",
    "Admin documentation" : "Administraatori dokumentatsioon",
    "Developer documentation" : "Arendaja dokumentatsioon",
    "No apps found for your version" : "Sinu versiooni jaoks ei leitud ühtegi rakendust",
    "Enable all" : "Luba kõik",
    "Enable" : "Lülita sisse",
    "Allow filesystem access" : "Luba juurdepääs failisüsteemile",
    "Revoke" : "Tühista",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome for Android",
    "Sync client - {os}" : "Kliendiprogramm - {os}",
    "This session" : "See sessioon",
    "Device" : "Seade",
    "Last activity" : "Viimane tegevus",
    "Devices & sessions" : "Seadmed & sessioonid",
    "Web, desktop and mobile clients currently logged in to your account." : "Sinu kontole hetkel sisse loginud veebi-, töölaua-, ja mobiilsed kliendid.",
    "App name" : "Rakenduse nimi",
    "Create new app password" : "Loo uus rakenduse parool",
    "Use the credentials below to configure your app or device." : "Rakenduse või seadme konfigureerimiseks kasutage allpool toodud mandaate.",
    "For security reasons this password will only be shown once." : "Turvalisuse huvides kuvatakse see parool ainult üks kord.",
    "Username" : "Kasutajanimi",
    "Password" : "Parool",
    "Done" : "Valmis",
    "Copied!" : "Kopeeritud!",
    "Copy" : "Kopeeri",
    "You do not have permissions to see the details of this user" : "Sul puuduvad õigused selle kasutaja üksikasjade vaatamiseks",
    "New password" : "Uus parool",
    "Delete user" : "Kustuta kasutaja",
    "Disable user" : "Keela kasutaja",
    "Enable user" : "Luba kasutaja",
    "Resend welcome email" : "Saada tervitusmeil uuesti",
    "{size} used" : "{size} kasutatud",
    "Welcome mail sent!" : "Tervitusmeil saadetud!",
    "Display name" : "Kuvatav nimi",
    "Email" : "E-post",
    "Group admin for" : "Grupi admin",
    "Quota" : "Mahupiir",
    "Language" : "Keel",
    "Storage location" : "Salvestusruumi asukoht",
    "User backend" : "Kasutaja taustarakendus",
    "Last login" : "Viimane sisselogimine",
    "Default language" : "Vaikekeel",
    "Default quota" : "Vaikimisi mahupiir",
    "Common languages" : "Levinud keeled",
    "All languages" : "Kõik keeled",
    "Your apps" : "Sinu rakendused",
    "Disabled apps" : "Keelatud rakendused",
    "Updates" : "Uuendused",
    "App bundles" : "Rakenduste kogumikud",
    "{license}-licensed" : "{license} litsents",
    "New user" : "Uus kasutaja",
    "Default quota:" : "Vaikekvoot:",
    "Show last login" : "Näita viimast sisselogimist",
    "Remove group" : "Eemalda grupp",
    "Admins" : "Haldurid",
    "Disabled users" : "Keelatud kasutajad",
    "Everyone" : "Igaüks",
    "Add group" : "Lisa grupp",
    "You are about to remove the group {group}. The users will NOT be deleted." : "Sa oled eemaldamas gruppi {group}. Selles grupis olevaid kasutajaid EI kustutata.",
    "Please confirm the group removal " : "Palun kinnita grupi eemaldamine",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Rakendus on lubatud, aga see vajab uuendamist. Sind suunatakse 5 sekundi pärast uuendamise lehele.",
    "SSL Root Certificates" : "SSL juursertifikaadid",
    "Common Name" : "Üldnimetus",
    "Valid until" : "Kehtib kuni",
    "Issued By" : "Välja antud",
    "Valid until %s" : "Kehtib kuni %s",
    "Import root certificate" : "Impordi root sertifikaat",
    "Administrator documentation" : "Administraatori dokumentatsioon",
    "Documentation" : "Dokumentatsioon",
    "Forum" : "Foorum",
    "None" : "Pole",
    "Login" : "Logi sisse",
    "Plain" : "Tavatekst",
    "NT LAN Manager" : "NT LAN Manager",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "E-kirjade server",
    "Open documentation" : "Ava dokumentatsioon",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "E-kirjad saatmise võimekus on olulile seadistada paroolide lähtestamiseks ja teavituste saatmiseks.",
    "Send mode" : "Saatmise viis",
    "Encryption" : "Krüpteerimine",
    "From address" : "Saatja aadress",
    "mail" : "e-mail",
    "Authentication method" : "Autentimise meetod",
    "Authentication required" : "Autentimine on vajalik",
    "Server address" : "Serveri aadress",
    "Port" : "Port",
    "Credentials" : "Kasutajatunnused",
    "SMTP Username" : "SMTP kasutajatunnus",
    "SMTP Password" : "SMTP parool",
    "Test email settings" : "Testi e-posti seadeid",
    "Send email" : "Saada kiri",
    "Security & setup warnings" : "Turva- ja paigalduse hoiatused",
    "All checks passed." : "Kõik kontrollid on läbitud.",
    "Version" : "Versioon",
    "Server-side encryption" : "Serveripoolne krüpteerimine",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Serveripoole krüpteerimine võimaldab serverisse üleslaetud faile krüpteerida. Sellega kaasnevad piirangud, näiteks jõudluskadu. Lülita see sisse ainult siis, kui vaja on.",
    "Enable server-side encryption" : "Luba serveripoolne krüpteerimine",
    "Please read carefully before activating server-side encryption: " : "Palun loe hoolikalt enne serveripoolse krüpteerimise lubamist:",
    "Enable encryption" : "Luba krüpteerimine",
    "Select default encryption module:" : "Määra vaikimisi krüpteerimise moodul:",
    "Start migration" : "Alusta kolimist",
    "Execute one task with each page loaded" : "Käivita toiming igal lehe laadimisel",
    "The cron.php needs to be executed by the system user \"%s\"." : "cron.php tuleb käivitada süsteemikasutaja \"%s\" poolt.",
    "Sharing" : "Jagamine",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Administraatorina saate jagamise valikuid täpselt seadistada. Lisateavet leiad dokumentatsioonist.",
    "Allow apps to use the Share API" : "Luba rakendustel kasutada Share API-t",
    "Allow users to share via link" : "Luba kasutajatel lingiga jagamist ",
    "Allow public uploads" : "Luba avalikud üleslaadimised",
    "Always ask for a password" : "Alati küsi parooli",
    "Enforce password protection" : "Sunni parooliga kaitsmine",
    "Set default expiration date" : "Määra vaikimisi aegumise kuupäev",
    "Expire after " : "Aegu pärast",
    "days" : "päeva",
    "Enforce expiration date" : "Sunnitud aegumise kuupäev",
    "Allow resharing" : "Luba edasijagamine",
    "Allow sharing with groups" : "Luba gruppidega jagamine",
    "Restrict users to only share with users in their groups" : "Luba kasutajatel jagada kasutajatega ainult oma grupi piires",
    "Exclude groups from sharing" : "Eemalda grupid jagamisest",
    "These groups will still be able to receive shares, but not to initiate them." : "Need grupid saavad vastu võtta jagamisi, kuid ise jagamisi algatada ei saa.",
    "Allow username autocompletion in share dialog. If this is disabled the full username or email address needs to be entered." : "Luba kasutajanime automaatne lõpetamine jagamisdialoogis. Kui see on keelatud, tuleb sisestada täielik kasutajanimi või e-posti aadress.",
    "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "Kuva avaliku lingiga üleslaadimise lehel lahtiütluste tekst. (Kuvatakse ainult siis, kui failide loend on peidetud.)",
    "This text will be shown on the public link upload page when the file list is hidden." : "Seda teksti näidatakse avaliku lingiga üleslaadimise lehel kui failide loend on peidetud.",
    "Personal" : "Isiklik",
    "Administration" : "Haldus",
    "Profile picture" : "Profiili pilt",
    "Upload new" : "Laadi uus üles",
    "Select from Files" : "Vali failidest",
    "Remove image" : "Eemalda pilt",
    "png or jpg, max. 20 MB" : "png või jpg, max. 20 MB",
    "Cancel" : "Loobu",
    "Choose as profile picture" : "Vali kui profiili pilt",
    "Details" : "Üksikasjad",
    "You are a member of the following groups:" : "Sa oled nende gruppide liige:",
    "Full name" : "Täielik nimi",
    "No display name set" : "Näidatavat nime pole veel määratud",
    "Your email address" : "Sinu e-posti aadress",
    "No email address set" : "E-posti aadressi pole veel määratud",
    "For password reset and notifications" : "Parooli lähestamiseks ja teadeteks",
    "Phone number" : "Telefoninumber",
    "Your phone number" : "Sinu telefoninumber",
    "Address" : "Aadress",
    "Your postal address" : "Sinu postiaadress",
    "Website" : "Veebileht",
    "It can take up to 24 hours before the account is displayed as verified." : "Võib võtta kuni 24 tundi enne kui konto kuvatakse kui kinnitatud.",
    "Help translate" : "Aita tõlkida",
    "Locale" : "Kasutuskoht",
    "Current password" : "Praegune parool",
    "Change password" : "Muuda parooli",
    "Store credentials" : "Säilita kasutajaandmed",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "cron.php on registreeritud webcron teenuses, et käivitada fail cron.php iga 15 minuti tagant üle http.",
    "Use system cron service to call the cron.php file every 15 minutes." : "Kasuta süsteemi cron teenust, et käivitada fail cron.php iga 15 minuti järel."
},
"nplurals=2; plural=(n != 1);");
